@@ -1,6 +1,6 @@
 # iban.py - functions for handling International Bank Account Numbers (IBANs)
 #
-# Copyright (C) 2011-2015 Arthur de Jong
+# Copyright (C) 2011-2016 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@ for the ISO 7064 Mod 97, 10 checksum. Each country uses its own format
 for the remainder of the number.
 
 Some countries may also use checksum algorithms within their number but
-this is currently not checked by this number.
+this is only checked for a few countries.
 
 More information:
 
@@ -40,6 +40,8 @@ More information:
 'GR1601101050000010547023795'
 >>> format('GR1601101050000010547023795')
 'GR16 0110 1050 0000 1054 7023 795'
+>>> calc_check_digits('BExx435411161155')
+'31'
 """
 
 import re
@@ -47,7 +49,7 @@ import re
 from stdnum import numdb
 from stdnum.exceptions import *
 from stdnum.iso7064 import mod_97_10
-from stdnum.util import clean
+from stdnum.util import clean, get_cc_module
 
 
 # our open copy of the IBAN database
@@ -59,6 +61,9 @@ _alphabet = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'
 # regular expression to check IBAN structure
 _struct_re = re.compile(r'([1-9][0-9]*)!([nac])')
 
+# cache of country codes to modules
+_country_modules = dict()
+
 
 def compact(number):
     """Convert the iban number to the minimal representation. This strips the
@@ -71,7 +76,20 @@ def _to_base10(number):
     check digits to the end) so it can be checked with the ISO 7064
     Mod 97, 10 algorithm."""
     # TODO: find out whether this should be in the mod_97_10 module
-    return ''.join(str(_alphabet.index(x)) for x in number[4:] + number[:4])
+    try:
+        return ''.join(
+            str(_alphabet.index(x)) for x in number[4:] + number[:4])
+    except Exception:
+        raise InvalidFormat()
+
+
+def calc_check_digits(number):
+    """Calculate the check digits that should be put in the number to make
+    it valid. Check digits in the supplied number are ignored.."""
+    number = compact(number)
+    # replace check digits with placeholders
+    number = ''.join((number[:2], '00', number[4:]))
+    return mod_97_10.calc_check_digits(_to_base10(number)[:-2])
 
 
 def _struct_to_re(structure):
@@ -87,29 +105,40 @@ def _struct_to_re(structure):
     return re.compile('^%s$' % _struct_re.sub(conv, structure))
 
 
-def validate(number):
-    """Checks to see if the number provided is a valid IBAN."""
+def _get_cc_module(cc):
+    """Get the VAT number module based on the country code."""
+    # Greece uses a "wrong" country code
+    cc = cc.lower()
+    if cc not in _country_modules:
+        _country_modules[cc] = get_cc_module(cc, 'iban')
+    return _country_modules[cc]
+
+
+def validate(number, check_country=True):
+    """Checks to see if the number provided is a valid IBAN. The country-
+    specific check can be disabled with the check_country argument."""
     number = compact(number)
-    try:
-        test_number = _to_base10(number)
-    except Exception:
-        raise InvalidFormat()
     # ensure that checksum is valid
-    mod_97_10.validate(test_number)
+    mod_97_10.validate(_to_base10(number))
     # look up the number
     info = _ibandb.info(number)
     # check if the bban part of number has the correct structure
     bban = number[4:]
     if not _struct_to_re(info[0][1].get('bban', '')).match(bban):
         raise InvalidFormat()
+    # check the country-specific module if it exists
+    if check_country:
+        module = _get_cc_module(number[:2])
+        if module:
+            module.validate(number)
     # return the compact representation
     return number
 
 
-def is_valid(number):
+def is_valid(number, check_country=True):
     """Checks to see if the number provided is a valid IBAN."""
     try:
-        return bool(validate(number))
+        return bool(validate(number, check_country=check_country))
     except ValidationError:
         return False
 
@@ -117,4 +146,7 @@ def is_valid(number):
 def format(number, separator=' '):
     """Reformat the passed number to the space-separated format."""
     number = compact(number)
+    module = _get_cc_module(number[:2])
+    if module and hasattr(module, 'format') and module.format != format:
+        return module.format(number, separator=separator)
     return separator.join(number[i:i + 4] for i in range(0, len(number), 4))
