@@ -1,7 +1,7 @@
 # imei.py - functions for handling International Mobile Equipment Identity
 #           (IMEI) numbers
 #
-# Copyright (C) 2010, 2011, 2012, 2013 Arthur de Jong
+# Copyright (C) 2010-2015 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -20,8 +20,13 @@
 
 """IMEI (International Mobile Equipment Identity).
 
-The  IMEI is used to identify mobile phones. The IMEI may optionally
-include a check digit which is validated using the Luhn algorithm.
+The  IMEI is used to identify mobile phones. An IMEI is 14, 15 (when the
+check digit is included) or 16 digits (IMEISV) long. The check digit is
+validated using the Luhn algorithm.
+
+More information:
+
+* https://en.wikipedia.org/wiki/International_Mobile_Equipment_Identity
 
 >>> validate('35686800-004141-20')
 '3568680000414120'
