@@ -28,12 +28,18 @@ digit), the owner, a country code, a size, type and equipment category as well
 as any operational marks. The standard is managed by the International
 Container Bureau (BIC).
 
+More information:
+
+* http://en.wikipedia.org/wiki/ISO_6346
+
 >>> validate('csqu3054383')
 'CSQU3054383'
 >>> validate('CSQU3054384')
 Traceback (most recent call last):
     ...
 InvalidChecksum: ...
+>>> format('tasu117 000 0')
+'TASU 117000 0'
 """
 
 import re
@@ -49,7 +55,7 @@ _iso6346_re = re.compile(r'^\w{3}(U|J|Z|R)\d{7}$')
 def compact(number):
     """Convert the number to the minimal representation. This strips the
     number of any valid separators and removes surrounding whitespace."""
-    return clean(number).strip().upper()
+    return clean(number, ' ').strip().upper()
 
 
 def calc_check_digit(number):
@@ -59,7 +65,7 @@ def calc_check_digit(number):
     alphabet = '0123456789A BCDEFGHIJK LMNOPQRSTU VWXYZ'
     return str(sum(
         alphabet.index(n) * pow(2, i)
-        for i, n in enumerate(number)) % 11)
+        for i, n in enumerate(number)) % 11 % 10)
 
 
 def validate(number):
@@ -81,3 +87,9 @@ def is_valid(number):
         return bool(validate(number))
     except ValidationError:
         return False
+
+
+def format(number):
+    """Reformat the passed number to the standard format."""
+    number = compact(number)
+    return ' '.join((number[:4], number[4:-1], number[-1:]))
